# Uptick for BitShares

Swiss army knife for interacting with the BitShares blockchain.

[![rtd master](https://readthedocs.org/projects/uptick/badge/?version=latest)](http://uptick.readthedocs.io/en/latest/)
[![codecov](https://codecov.io/gh/xeroc/uptick/branch/master/graph/badge.svg)](https://codecov.io/gh/xeroc/uptick)
[![Travis master](https://travis-ci.org/xeroc/uptick.png?branch=master)](https://travis-ci.org/xeroc/uptick)
[![Travis develop](https://travis-ci.org/xeroc/uptick.png?branch=develop)](https://travis-ci.org/xeroc/uptick)

[![PyPI](https://img.shields.io/pypi/dm/uptick.svg?maxAge=2592000)]()
[![PyPI](https://img.shields.io/pypi/dw/uptick.svg?maxAge=2592000)]()

**Develop**

[![docs develop](https://readthedocs.org/projects/uptick/badge/?version=develop)](http://uptick.readthedocs.io/en/develop/)
[![Travis develop](https://travis-ci.org/xeroc/uptick.png?branch=develop)](https://travis-ci.org/xeroc/uptick)
[![codecov develop](https://codecov.io/gh/xeroc/uptick/branch/develop/graph/badge.svg)](https://codecov.io/gh/xeroc/uptick)

## Installation

```
pip3 install uptick
```

## Documentation

The full-length documentation can be found on [http://uptick.rocks](http://uptick.rocks).

## Public API

The public API node at `this.uptick.rocks` serves as an experimental
endpoint. 

* Use it for prototyping of your tools
* Use it for testing
* Do not expect it to be reliable
* Do not spam it with unnecessary load

# IMPORTANT NOTE

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.
